package com.diagbot.repository;


import com.diagbot.entity.node.base.BaseNode;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;
import org.springframework.data.repository.query.Param;

import java.util.List;

public interface BaseNodeRepository extends Neo4jRepository<BaseNode, Long> {

    List<BaseNode> findByNameIs(String name);

    @Query("MATCH (n) RETURN DISTINCT(LABELS(n))")
    List<String> getLabels();

    @Query("MATCH (c:药品化学物质类别)<-[r:药品相关药品化学物质类别]-(y:药品代码通用名)-[r1:药品相关药品通用名称]->(m:药品通用名称) " +
            " RETURN DISTINCT(m.name)+'::'+c.name")
    List<String> getMedHuaXueClass();

    @Query("MATCH (c:药品治疗学类别)<-[r:药品相关药品治疗学类别]-(y:药品代码通用名)-[r1:药品相关药品通用名称]->(m:药品通用名称) " +
            " RETURN DISTINCT(m.name)+'::'+c.name")
    List<String> getMedZhiLiaoClass();

    @Query("MATCH (c:药品药理学类别)<-[r:药品相关药品药理学类别]-(y:药品代码通用名)-[r1:药品相关药品通用名称]->(m:药品通用名称) " +
            " RETURN DISTINCT(m.name)+'::'+c.name")
    List<String> getMedYaoLiClass();

    @Query("MATCH (c:药品解剖学类别)<-[r:药品相关药品解剖学类别]-(y:药品代码通用名)-[r1:药品相关药品通用名称]->(m:药品通用名称) " +
            " RETURN DISTINCT(m.name)+'::'+c.name")
    List<String> getMedJiePouClass();

    @Query("match(s:症状) return distinct s.name")
    List<String> getSymptomClass();

    @Query("match(d:医保疾病名称)-[r:医保疾病名称相关性别]->(h) return DISTINCT d.name+'&'+h.name")
    List<String> getDisSexClass();

    @Query("match(d:医保疾病名称)-[r:医保疾病名称相关年龄]->(h) return DISTINCT d.name+'&'+h.name")
    List<String> getDisAgeClass();

    @Query("match(d:医保疾病名称)-[r:医保疾病名称相关发病率]->(h) return DISTINCT d.name+'&'+h.name")
    List<String> getDisdistributionClass();

    @Query("MATCH (n) WHERE EXISTS(n.拼音编码) AND n.拼音编码={py} RETURN n.name")
    List<String> getNamebyPinYin(@Param("py") String pycode);
}